#!/bin/sh
# Since this is in /testing, an absolute path will do for now.
# If it gets moved to the main tree replacing gimp-print we'll
# probably have to use a chroot to run this.  Also, anyone
# using ROOT= with installpkg may have to chroot to the
# mount to run this command:
if [ -x /usr/sbin/cups-genppd.5.0 ]; then
  echo "Generating PPD files for CUPS:"
  /usr/sbin/cups-genppd.5.0
fi
( cd usr/lib ; rm -rf libgutenprintui.so.1 )
( cd usr/lib ; ln -sf libgutenprintui.so.1.0.0 libgutenprintui.so.1 )
( cd usr/lib ; rm -rf libgutenprintui.so )
( cd usr/lib ; ln -sf libgutenprintui.so.1.0.0 libgutenprintui.so )
( cd usr/lib ; rm -rf libgutenprintui2.so.1 )
( cd usr/lib ; ln -sf libgutenprintui2.so.1.0.0 libgutenprintui2.so.1 )
( cd usr/lib ; rm -rf libgutenprint.so.2 )
( cd usr/lib ; ln -sf libgutenprint.so.2.0.0 libgutenprint.so.2 )
( cd usr/lib ; rm -rf libgutenprint.so )
( cd usr/lib ; ln -sf libgutenprint.so.2.0.0 libgutenprint.so )
( cd usr/lib ; rm -rf libgutenprintui2.so )
( cd usr/lib ; ln -sf libgutenprintui2.so.1.0.0 libgutenprintui2.so )
( cd usr/doc/gutenprint-5.0.1 ; rm -rf samples )
( cd usr/doc/gutenprint-5.0.1 ; ln -sf /usr/share/gutenprint/samples samples )
( cd usr/doc/gutenprint-5.0.1 ; rm -rf doc )
( cd usr/doc/gutenprint-5.0.1 ; ln -sf /usr/share/gutenprint/doc doc )
